@@ -1,4 +1,7 @@
-__version__ = (9, 0, 8021)
+__version__ = "9.2.14"
+
+import logging
+from typing import Set
 
 from .block import Block
 from . import statement as Stmt
@@ -6,17 +9,31 @@ from . import expression as Expr
 from .statement import Assignment
 from .expression import Expression, Const, Tmp, Register, UnaryOp, BinaryOp
 from .converter_common import Converter
-from .converter_vex import VEXIRSBConverter
 from .manager import Manager
 
+log = logging.getLogger(__name__)
+
+
+available_converters: Set[str] = set()
+
+try:
+    from .converter_vex import VEXIRSBConverter
+    import pyvex
+    available_converters.add("vex")
+except ImportError as e:
+    log.debug("Could not import VEXIRSBConverter")
+    log.debug(e)
+
 try:
-    from angr.engines import pcode
     from .converter_pcode import PCodeIRSBConverter
-except ImportError:
-    pcode = None
+    from angr.engines import pcode
+    available_converters.add("pcode")
+except ImportError as e:
+    log.debug("Could not import PCodeIRSBConverter")
+    log.debug(e)
+
 
 class IRSBConverter(Converter):
-
     @staticmethod
     def convert(irsb, manager):  # pylint:disable=arguments-differ
         """
@@ -27,7 +44,9 @@ class IRSBConverter(Converter):
         :return:        Returns the converted block
         """
 
-        if pcode and isinstance(irsb, pcode.lifter.IRSB):
+        if "pcode" in available_converters and isinstance(irsb, pcode.lifter.IRSB):
             return PCodeIRSBConverter.convert(irsb, manager)
-        else:
+        elif "vex" in available_converters and isinstance(irsb, pyvex.IRSB):
             return VEXIRSBConverter.convert(irsb, manager)
+        else:
+            raise ValueError("No converter available for %s" % type(irsb))
